@@ -2,8 +2,8 @@ package EachTest;
 use Test::Roo::Role;
 
 has counter => (
-    is => 'rw',
-    lazy => 1,
+    is      => 'rw',
+    lazy    => 1,
     builder => 1,
 );
 
@@ -11,12 +11,14 @@ requires '_build_counter';
 
 before each_test => sub {
     my $self = shift;
-    $self->counter( $self->counter + 1);
+    pass("starting before module modifier");
+    $self->counter( $self->counter + 1 );
 };
 
 after each_test => sub {
     my $self = shift;
-    $self->counter( $self->counter - 1);
+    $self->counter( $self->counter - 1 );
+    pass("finishing after module modifier");
 };
 
 test 'positive' => sub { ok( shift->counter, "counter positive" ) };
